@@ -23,20 +23,24 @@ display_bus = displayio.FourWire(
 )
 time.sleep(1)
 
-display = adafruit_ssd1675.SSD1675(display_bus, width=250, height=122, rotation=90)
+display = adafruit_ssd1675.SSD1675(display_bus, width=250, height=122, rotation=270)
 
 g = displayio.Group()
 
-f = open("/display-ruler.bmp", "rb")
+with open("/display-ruler.bmp", "rb") as f:
+    pic = displayio.OnDiskBitmap(f)
+    # CircuitPython 6 & 7 compatible
+    t = displayio.TileGrid(
+        pic, pixel_shader=getattr(pic, "pixel_shader", displayio.ColorConverter())
+    )
+    # CircuitPython 7 compatible only
+    # t = displayio.TileGrid(pic, pixel_shader=pic.pixel_shader)
+    g.append(t)
 
-pic = displayio.OnDiskBitmap(f)
-t = displayio.TileGrid(pic, pixel_shader=displayio.ColorConverter())
-g.append(t)
+    display.show(g)
 
-display.show(g)
+    display.refresh()
 
-display.refresh()
+    print("refreshed")
 
-print("refreshed")
-
-time.sleep(120)
+    time.sleep(120)
